@@ -13,8 +13,8 @@
 	Library General Public License for more details.
 
 	You should have received a copy of the GNU Library General Public
-	License along with this library; if not, write to the 
-	Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
+	License along with this library; if not, write to the
+	Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 	Boston, MA  02111-1307  USA.
 */
 
@@ -27,6 +27,17 @@
 #ifndef AUDIOFILE_H
 #define AUDIOFILE_H
 
+#include <sys/types.h>
+#include <aupvlist.h>
+
+#define LIBAUDIOFILE_MAJOR_VERSION 0
+#define LIBAUDIOFILE_MINOR_VERSION 2
+
+#ifdef __cplusplus
+extern "C"
+{
+#endif /* __cplusplus */
+
 /*
 	AFvirtualfile is the preferred type to use; AF_VirtualFile will go
 	away.
@@ -34,14 +45,6 @@
 typedef struct _AF_VirtualFile AFvirtualfile;
 typedef struct _AF_VirtualFile AF_VirtualFile;
 
-#include <sys/types.h>
-#include "aupvlist.h"
-
-#ifdef __cplusplus
-extern "C"
-{
-#endif /* __cplusplus */
-
 typedef struct _AFfilesetup *AFfilesetup;
 typedef struct _AFfilehandle *AFfilehandle;
 typedef void (*AFerrfunc)(long, const char *);
@@ -89,7 +92,7 @@ enum
 {
 	AF_LOOP_MODE_NOLOOP = 0,
 	AF_LOOP_MODE_FORW = 1,
-	AF_LOOP_MODE_FORWBACKW = 2
+	AF_LOOP_MODE_FORWBAKW = 2
 };
 
 enum
@@ -138,14 +141,14 @@ enum
 	AF_MISC_APPL = 205,	/* application-specific data */
 	AF_MISC_MIDI = 206,	/* MIDI exclusive data */
 	AF_MISC_PCMMAP = 207,	/* PCM mapping information (future use) */
-	AF_MISC_NeXT = 208,	/* misc binary data appended to NeXT hdr */
+	AF_MISC_NeXT = 208,	/* misc binary data appended to NeXT header */
 	AF_MISC_IRCAM_PEAKAMP = 209,	/* peak amplitude information */
 	AF_MISC_IRCAM_COMMENT = 210,	/* BICSF text comment */
 	AF_MISC_COMMENT = 210,	/* general text comment */
 
-	AF_MISC_ICMT = AF_MISC_COMMENT,	/* comments chunk (WAV format) */
-	AF_MISC_ICRD = 211,  /* creation date (WAV format) */
-	AF_MISC_ISFT = 212  /* software name (WAV format) */
+	AF_MISC_ICMT = AF_MISC_COMMENT,	/* comments chunk (WAVE format) */
+	AF_MISC_ICRD = 211,  /* creation date (WAVE format) */
+	AF_MISC_ISFT = 212  /* software name (WAVE format) */
 };
 
 enum
@@ -402,7 +405,6 @@ AFfilehandle afOpenFD (int fd, const char *mode, AFfilesetup setup);
 AFfilehandle afOpenNamedFD (int fd, const char *mode, AFfilesetup setup,
 	const char *filename);
 
-int afGetFD (AFfilehandle file);
 void afSaveFilePosition (AFfilehandle file);
 void afRestoreFilePosition (AFfilehandle file);
 int afSyncFile (AFfilehandle file);
@@ -422,9 +424,7 @@ AFframecount afSeekFrame (AFfilehandle, int track, AFframecount frameoffset);
 AFfileoffset afTellFrame (AFfilehandle, int track);
 AFfileoffset afGetTrackBytes (AFfilehandle, int track);
 float afGetFrameSize (AFfilehandle, int track, int expand3to4);
-#if 0
 float afGetVirtualFrameSize (AFfilehandle, int track, int expand3to4);
-#endif
 
 /* track data: AES data */
 /* afInitAESChannelData is obsolete -- use afInitAESChannelDataTo() */
@@ -503,7 +503,6 @@ void afGetVirtualCompressionParams (AFfilehandle, int track, int *compression,
 	AUpvlist params, int parameterCount);
 #endif
 
-#if 0
 /* track data: pcm mapping */
 void afInitPCMMapping (AFfilesetup filesetup, int track,
 	double slope, double intercept, double minClip, double maxClip);
@@ -520,8 +519,6 @@ int afSetVirtualPCMMapping (AFfilehandle file, int track,
 void afGetVirtualPCMMapping (AFfilehandle file, int track,
 	double *slope, double *intercept, double *minClip, double *maxClip);
 
-#endif
-
 /* track data: data offset within the file */
 /* initialize for raw reading only */
 void afInitDataOffset(AFfilesetup, int track, AFfileoffset offset);
