@@ -59,10 +59,13 @@
 void setupdsp (int audiofd, int channelCount);
 void usage (void);
 
+/* BUFFER_FRAMES represents the size of the buffer in frames. */
+#define BUFFER_FRAMES 4096
+
 int main (int argc, char **argv)
 {
 	AFfilehandle	file;
-	AFframecount	frameCount;
+	AFframecount	frameCount, framesRead;
 	int		sampleFormat, sampleWidth, channelCount, frameSize;
 	void		*buffer;
 	int		audiofd;
@@ -95,8 +98,7 @@ int main (int argc, char **argv)
 		exit(-1);
 	}
 
-	buffer = malloc(frameCount * frameSize);
-	afReadFrames(file, AF_DEFAULT_TRACK, buffer, frameCount);
+	buffer = malloc(BUFFER_FRAMES * frameSize);
 
 	audiofd = open("/dev/dsp", O_WRONLY);
 	if (audiofd < 0)
@@ -107,7 +109,17 @@ int main (int argc, char **argv)
 
 	setupdsp(audiofd, channelCount);
 
-	write(audiofd, buffer, frameCount * frameSize);
+	framesRead = afReadFrames(file, AF_DEFAULT_TRACK, buffer,
+		BUFFER_FRAMES);
+
+	while (framesRead > 0)
+	{
+		printf("read %ld frames\n", framesRead);
+		write(audiofd, buffer, framesRead * frameSize);
+		framesRead = afReadFrames(file, AF_DEFAULT_TRACK, buffer,
+			BUFFER_FRAMES);
+	}
+
 	close(audiofd);
 	free(buffer);
 
