@@ -1,7 +1,7 @@
 /*
 	Audio File Library
 
-	Copyright 1998, Michael Pruett <michael@68k.org>
+	Copyright 1998-2000, Michael Pruett <michael@68k.org>
 
 	This program is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License as
@@ -32,6 +32,12 @@
 
 const char *paramtypename (int paramtype);
 
+#ifdef DEBUG
+#define DEBG printf
+#else
+#define DEBG
+#endif
+
 int main (int ac, char **av)
 {
 	AUpvlist	formatlist;
@@ -43,7 +49,8 @@ int main (int ac, char **av)
 	formatlist = afQuery(AF_QUERYTYPE_FILEFMT, AF_QUERY_IDS, 0, 0, 0);
 	formatcount = afQueryLong(AF_QUERYTYPE_FILEFMT, AF_QUERY_ID_COUNT, 0, 0, 0);
 
-	printf("formatcount = %d\n", formatcount);
+	DEBG("formatcount = %d\n", formatcount);
+
 	AUpvgetval(formatlist, 0, &flist);
 	AUpvfree(formatlist);
 
@@ -53,26 +60,26 @@ int main (int ac, char **av)
 		char	*formatstring;
 
 		format = flist[i];
-		printf("format = %ld\n", format);
+		DEBG("format = %ld\n", format);
 		formatstring = afQueryPointer(AF_QUERYTYPE_FILEFMT, AF_QUERY_NAME,
 			format, 0, 0);
-		printf("format = %s\n", formatstring);
+		DEBG("format = %s\n", formatstring);
 
 		lvalue = afQueryLong(AF_QUERYTYPE_INST, AF_QUERY_SUPPORTED,
 			format, 0, 0);
-		printf("instrument query: supported: %ld\n", lvalue);
+		DEBG("instrument query: supported: %ld\n", lvalue);
 
 		lvalue = afQueryLong(AF_QUERYTYPE_INST, AF_QUERY_MAX_NUMBER,
 			format, 0, 0);
-		printf("instrument query: maximum number: %ld\n", lvalue);
+		DEBG("instrument query: maximum number: %ld\n", lvalue);
 
 		lvalue = afQueryLong(AF_QUERYTYPE_INSTPARAM, AF_QUERY_SUPPORTED,
 			format, 0, 0);
-		printf("instrument parameter query: supported: %ld\n", lvalue);
+		DEBG("instrument parameter query: supported: %ld\n", lvalue);
 
 		lvalue = afQueryLong(AF_QUERYTYPE_INSTPARAM, AF_QUERY_ID_COUNT,
 			format, 0, 0);
-		printf("instrument parameter query: id count: %ld\n", lvalue);
+		DEBG("instrument parameter query: id count: %ld\n", lvalue);
 
 		larray = afQueryPointer(AF_QUERYTYPE_INSTPARAM, AF_QUERY_IDS,
 			format, 0, 0);
@@ -84,12 +91,12 @@ int main (int ac, char **av)
 			{
 				int	paramtype;
 
-				printf("instrument parameter query: id: %ld\n", larray[i]);
+				DEBG("instrument parameter query: id: %ld\n", larray[i]);
 				paramtype = afQueryLong(AF_QUERYTYPE_INSTPARAM,
 					AF_QUERY_TYPE, format, larray[i], 0);
-				printf("	type of parameter: %s\n",
+				DEBG("	type of parameter: %s\n",
 					paramtypename(paramtype));
-				printf("	name of parameter: %s\n",
+				DEBG("	name of parameter: %s\n",
 				       (char *)
 					afQueryPointer(AF_QUERYTYPE_INSTPARAM, AF_QUERY_NAME,
 						format, larray[i], 0));
